/***************************************************

  data.c : リバーシ用データ

	   Copyright (C) 1997-2005,2014 Makoto Hiroi

****************************************************/
#include  "reversi.h"


/* 駒の反転をチェックするデータ 64 * 8 方向 */
char  reverse_table[512][8] = {
	 1,  2,  3,  4,  5,  6,  7, -1,	/* 0, 0 右方向 */
	 8, 16, 24, 32, 40, 48, 56, -1,	/* 0, 0 下方向 */
	 9, 18, 27, 36, 45, 54, 63, -1,	/* 0, 0 右下方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 0, 0 右上方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 0, 0 上方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 0, 0 左下方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 0, 0 左方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 0, 0 左上方向 */

	 2,  3,  4,  5,  6,  7, -1, -1,	/* 1, 0 右方向 */
	10, 19, 28, 37, 46, 55, -1, -1,	/* 1, 0 右下方向 */
	 9, 17, 25, 33, 41, 49, 57, -1,	/* 1, 0 下方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 1, 0 左下方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 1, 0 左方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 1, 0 上方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 1, 0 右上方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 1, 0 左上方向 */

	 3,  4,  5,  6,  7, -1, -1, -1,	/* 2, 0 右方向 */
	11, 20, 29, 38, 47, -1, -1, -1,	/* 2, 0 右下方向 */
	10, 18, 26, 34, 42, 50, 58, -1,	/* 2, 0 下方向 */
	 9, 16, -1, -1, -1, -1, -1, -1,	/* 2, 0 左下方向 */
	 1,  0, -1, -1, -1, -1, -1, -1,	/* 2, 0 左方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 2, 0 上方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 2, 0 右上方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 2, 0 左上方向 */

	 4,  5,  6,  7, -1, -1, -1, -1,	/* 3, 0 右方向 */
	12, 21, 30, 39, -1, -1, -1, -1,	/* 3, 0 右下方向 */
	11, 19, 27, 35, 43, 51, 59, -1,	/* 3, 0 下方向 */
	10, 17, 24, -1, -1, -1, -1, -1,	/* 3, 0 左下方向 */
	 2,  1,  0, -1, -1, -1, -1, -1,	/* 3, 0 左方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 3, 0 上方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 3, 0 右上方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 3, 0 左上方向 */

	 5,  6,  7, -1, -1, -1, -1, -1,	/* 4, 0 右方向 */
	13, 22, 31, -1, -1, -1, -1, -1,	/* 4, 0 右下方向 */
	12, 20, 28, 36, 44, 52, 60, -1,	/* 4, 0 下方向 */
	11, 18, 25, 32, -1, -1, -1, -1,	/* 4, 0 左下方向 */
	 3,  2,  1,  0, -1, -1, -1, -1,	/* 4, 0 左方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 4, 0 右上方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 4, 0 上方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 4, 0 左上方向 */

	 6,  7, -1, -1, -1, -1, -1, -1,	/* 5, 0 右方向 */
	14, 23, -1, -1, -1, -1, -1, -1,	/* 5, 0 右下方向 */
	13, 21, 29, 37, 45, 53, 61, -1,	/* 5, 0 下方向 */
	12, 19, 26, 33, 40, -1, -1, -1,	/* 5, 0 左下方向 */
	 4,  3,  2,  1,  0, -1, -1, -1,	/* 5, 0 左方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 5, 0 上方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 5, 0 右上方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 5, 0 左上方向 */

	14, 22, 30, 38, 46, 54, 62, -1,	/* 6, 0 下方向 */
	13, 20, 27, 34, 41, 48, -1, -1,	/* 6, 0 左下方向 */
	 5,  4,  3,  2,  1,  0, -1, -1,	/* 6, 0 左方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 6, 0 右方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 6, 0 右下方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 6, 0 右上方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 6, 0 上方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 6, 0 左上方向 */

	15, 23, 31, 39, 47, 55, 63, -1,	/* 7, 0 下方向 */
	 6,  5,  4,  3,  2,  1,  0, -1,	/* 7, 0 左方向 */
	14, 21, 28, 35, 42, 49, 56, -1,	/* 7, 0 左下方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 7, 0 上方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 7, 0 右上方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 7, 0 右方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 7, 0 右下方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 7, 0 左上方向 */

	 9, 10, 11, 12, 13, 14, 15, -1,	/* 0, 1 右方向 */
	17, 26, 35, 44, 53, 62, -1, -1,	/* 0, 1 右下方向 */
	16, 24, 32, 40, 48, 56, -1, -1,	/* 0, 1 下方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 0, 1 上方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 0, 1 右上方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 0, 1 左下方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 0, 1 左方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 0, 1 左上方向 */

	10, 11, 12, 13, 14, 15, -1, -1,	/* 1, 1 右方向 */
	18, 27, 36, 45, 54, 63, -1, -1,	/* 1, 1 右下方向 */
	17, 25, 33, 41, 49, 57, -1, -1,	/* 1, 1 下方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 1, 1 上方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 1, 1 右上方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 1, 1 左下方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 1, 1 左方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 1, 1 左上方向 */

	11, 12, 13, 14, 15, -1, -1, -1,	/* 2, 1 右方向 */
	19, 28, 37, 46, 55, -1, -1, -1,	/* 2, 1 右下方向 */
	18, 26, 34, 42, 50, 58, -1, -1,	/* 2, 1 下方向 */
	17, 24, -1, -1, -1, -1, -1, -1,	/* 2, 1 左下方向 */
	 9,  8, -1, -1, -1, -1, -1, -1,	/* 2, 1 左方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 2, 1 上方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 2, 1 右上方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 2, 1 左上方向 */

	12, 13, 14, 15, -1, -1, -1, -1,	/* 3, 1 右方向 */
	20, 29, 38, 47, -1, -1, -1, -1,	/* 3, 1 右下方向 */
	19, 27, 35, 43, 51, 59, -1, -1,	/* 3, 1 下方向 */
	18, 25, 32, -1, -1, -1, -1, -1,	/* 3, 1 左下方向 */
	10,  9,  8, -1, -1, -1, -1, -1,	/* 3, 1 左方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 3, 1 上方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 3, 1 右上方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 3, 1 左上方向 */

	13, 14, 15, -1, -1, -1, -1, -1,	/* 4, 1 右方向 */
	21, 30, 39, -1, -1, -1, -1, -1,	/* 4, 1 右下方向 */
	20, 28, 36, 44, 52, 60, -1, -1,	/* 4, 1 下方向 */
	19, 26, 33, 40, -1, -1, -1, -1,	/* 4, 1 左下方向 */
	11, 10,  9,  8, -1, -1, -1, -1,	/* 4, 1 左方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 4, 1 上方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 4, 1 右上方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 4, 1 左上方向 */

	14, 15, -1, -1, -1, -1, -1, -1,	/* 5, 1 右方向 */
	22, 31, -1, -1, -1, -1, -1, -1,	/* 5, 1 右下方向 */
	21, 29, 37, 45, 53, 61, -1, -1,	/* 5, 1 下方向 */
	20, 27, 34, 41, 48, -1, -1, -1,	/* 5, 1 左下方向 */
	12, 11, 10,  9,  8, -1, -1, -1,	/* 5, 1 左方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 5, 1 上方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 5, 1 右上方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 5, 1 左上方向 */

	22, 30, 38, 46, 54, 62, -1, -1,	/* 6, 1 下方向 */
	21, 28, 35, 42, 49, 56, -1, -1,	/* 6, 1 左下方向 */
	13, 12, 11, 10,  9,  8, -1, -1,	/* 6, 1 左方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 6, 1 上方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 6, 1 右上方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 6, 1 右方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 6, 1 右下方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 6, 1 左上方向 */

	23, 31, 39, 47, 55, 63, -1, -1,	/* 7, 1 下方向 */
	22, 29, 36, 43, 50, 57, -1, -1,	/* 7, 1 左下方向 */
	14, 13, 12, 11, 10,  9,  8, -1,	/* 7, 1 左方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 7, 1 上方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 7, 1 右上方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 7, 1 右方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 7, 1 右下方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 7, 1 左上方向 */

	 8,  0, -1, -1, -1, -1, -1, -1,	/* 0, 2 上方向 */
	 9,  2, -1, -1, -1, -1, -1, -1,	/* 0, 2 右上方向 */
	17, 18, 19, 20, 21, 22, 23, -1,	/* 0, 2 右方向 */
	25, 34, 43, 52, 61, -1, -1, -1,	/* 0, 2 右下方向 */
	24, 32, 40, 48, 56, -1, -1, -1,	/* 0, 2 下方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 0, 2 左下方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 0, 2 左方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 0, 2 左上方向 */

	 9,  1, -1, -1, -1, -1, -1, -1,	/* 1, 2 上方向 */
	10,  3, -1, -1, -1, -1, -1, -1,	/* 1, 2 右上方向 */
	18, 19, 20, 21, 22, 23, -1, -1,	/* 1, 2 右方向 */
	26, 35, 44, 53, 62, -1, -1, -1,	/* 1, 2 右下方向 */
	25, 33, 41, 49, 57, -1, -1, -1,	/* 1, 2 下方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 1, 2 左下方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 1, 2 左方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 1, 2 左上方向 */

	10,  2, -1, -1, -1, -1, -1, -1,	/* 2, 2 上方向 */
	11,  4, -1, -1, -1, -1, -1, -1,	/* 2, 2 右上方向 */
	19, 20, 21, 22, 23, -1, -1, -1,	/* 2, 2 右方向 */
	27, 36, 45, 54, 63, -1, -1, -1,	/* 2, 2 右下方向 */
	26, 34, 42, 50, 58, -1, -1, -1,	/* 2, 2 下方向 */
	25, 32, -1, -1, -1, -1, -1, -1,	/* 2, 2 左下方向 */
	17, 16, -1, -1, -1, -1, -1, -1,	/* 2, 2 左方向 */
	 9,  0, -1, -1, -1, -1, -1, -1,	/* 2, 2 左上方向 */

	11,  3, -1, -1, -1, -1, -1, -1,	/* 3, 2 上方向 */
	12,  5, -1, -1, -1, -1, -1, -1,	/* 3, 2 右上方向 */
	20, 21, 22, 23, -1, -1, -1, -1,	/* 3, 2 右方向 */
	28, 37, 46, 55, -1, -1, -1, -1,	/* 3, 2 右下方向 */
	27, 35, 43, 51, 59, -1, -1, -1,	/* 3, 2 下方向 */
	26, 33, 40, -1, -1, -1, -1, -1,	/* 3, 2 左下方向 */
	18, 17, 16, -1, -1, -1, -1, -1,	/* 3, 2 左方向 */
	10,  1, -1, -1, -1, -1, -1, -1,	/* 3, 2 左上方向 */

	12,  4, -1, -1, -1, -1, -1, -1,	/* 4, 2 上方向 */
	13,  6, -1, -1, -1, -1, -1, -1,	/* 4, 2 右上方向 */
	21, 22, 23, -1, -1, -1, -1, -1,	/* 4, 2 右方向 */
	29, 38, 47, -1, -1, -1, -1, -1,	/* 4, 2 右下方向 */
	28, 36, 44, 52, 60, -1, -1, -1,	/* 4, 2 下方向 */
	27, 34, 41, 48, -1, -1, -1, -1,	/* 4, 2 左下方向 */
	19, 18, 17, 16, -1, -1, -1, -1,	/* 4, 2 左方向 */
	11,  2, -1, -1, -1, -1, -1, -1,	/* 4, 2 左上方向 */

	13,  5, -1, -1, -1, -1, -1, -1,	/* 5, 2 上方向 */
	14,  7, -1, -1, -1, -1, -1, -1,	/* 5, 2 右上方向 */
	22, 23, -1, -1, -1, -1, -1, -1,	/* 5, 2 右方向 */
	30, 39, -1, -1, -1, -1, -1, -1,	/* 5, 2 右下方向 */
	29, 37, 45, 53, 61, -1, -1, -1,	/* 5, 2 下方向 */
	28, 35, 42, 49, 56, -1, -1, -1,	/* 5, 2 左下方向 */
	20, 19, 18, 17, 16, -1, -1, -1,	/* 5, 2 左方向 */
	12,  3, -1, -1, -1, -1, -1, -1,	/* 5, 2 左上方向 */

	14,  6, -1, -1, -1, -1, -1, -1,	/* 6, 2 上方向 */
	30, 38, 46, 54, 62, -1, -1, -1,	/* 6, 2 下方向 */
	29, 36, 43, 50, 57, -1, -1, -1,	/* 6, 2 左下方向 */
	21, 20, 19, 18, 17, 16, -1, -1,	/* 6, 2 左方向 */
	13,  4, -1, -1, -1, -1, -1, -1,	/* 6, 2 左上方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 6, 2 右下方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 6, 2 右方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 6, 2 右上方向 */

	15,  7, -1, -1, -1, -1, -1, -1,	/* 7, 2 上方向 */
	31, 39, 47, 55, 63, -1, -1, -1,	/* 7, 2 下方向 */
	30, 37, 44, 51, 58, -1, -1, -1,	/* 7, 2 左下方向 */
	22, 21, 20, 19, 18, 17, 16, -1,	/* 7, 2 左方向 */
	14,  5, -1, -1, -1, -1, -1, -1,	/* 7, 2 左上方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 7, 2 右上方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 7, 2 右方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 7, 2 右下方向 */

	16,  8,  0, -1, -1, -1, -1, -1,	/* 0, 3 上方向 */
	17, 10,  3, -1, -1, -1, -1, -1,	/* 0, 3 右上方向 */
	25, 26, 27, 28, 29, 30, 31, -1,	/* 0, 3 右方向 */
	33, 42, 51, 60, -1, -1, -1, -1,	/* 0, 3 右下方向 */
	32, 40, 48, 56, -1, -1, -1, -1,	/* 0, 3 下方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 0, 3 左下方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 0, 3 左方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 0, 3 左上方向 */

	17,  9,  1, -1, -1, -1, -1, -1,	/* 1, 3 上方向 */
	18, 11,  4, -1, -1, -1, -1, -1,	/* 1, 3 右上方向 */
	26, 27, 28, 29, 30, 31, -1, -1,	/* 1, 3 右方向 */
	34, 43, 52, 61, -1, -1, -1, -1,	/* 1, 3 右下方向 */
	33, 41, 49, 57, -1, -1, -1, -1,	/* 1, 3 下方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 1, 3 左下方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 1, 3 左方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 1, 3 左上方向 */

	18, 10,  2, -1, -1, -1, -1, -1,	/* 2, 3 上方向 */
	19, 12,  5, -1, -1, -1, -1, -1,	/* 2, 3 右上方向 */
	27, 28, 29, 30, 31, -1, -1, -1,	/* 2, 3 右方向 */
	35, 44, 53, 62, -1, -1, -1, -1,	/* 2, 3 右下方向 */
	34, 42, 50, 58, -1, -1, -1, -1,	/* 2, 3 下方向 */
	33, 40, -1, -1, -1, -1, -1, -1,	/* 2, 3 左下方向 */
	25, 24, -1, -1, -1, -1, -1, -1,	/* 2, 3 左方向 */
	17,  8, -1, -1, -1, -1, -1, -1,	/* 2, 3 左上方向 */

	19, 11,  3, -1, -1, -1, -1, -1,	/* 3, 3 上方向 */
	20, 13,  6, -1, -1, -1, -1, -1,	/* 3, 3 右上方向 */
	28, 29, 30, 31, -1, -1, -1, -1,	/* 3, 3 右方向 */
	36, 45, 54, 63, -1, -1, -1, -1,	/* 3, 3 右下方向 */
	35, 43, 51, 59, -1, -1, -1, -1,	/* 3, 3 下方向 */
	34, 41, 48, -1, -1, -1, -1, -1,	/* 3, 3 左下方向 */
	26, 25, 24, -1, -1, -1, -1, -1,	/* 3, 3 左方向 */
	18,  9,  0, -1, -1, -1, -1, -1,	/* 3, 3 左上方向 */

	20, 12,  4, -1, -1, -1, -1, -1,	/* 4, 3 上方向 */
	21, 14,  7, -1, -1, -1, -1, -1,	/* 4, 3 右上方向 */
	29, 30, 31, -1, -1, -1, -1, -1,	/* 4, 3 右方向 */
	37, 46, 55, -1, -1, -1, -1, -1,	/* 4, 3 右下方向 */
	36, 44, 52, 60, -1, -1, -1, -1,	/* 4, 3 下方向 */
	35, 42, 49, 56, -1, -1, -1, -1,	/* 4, 3 左下方向 */
	27, 26, 25, 24, -1, -1, -1, -1,	/* 4, 3 左方向 */
	19, 10,  1, -1, -1, -1, -1, -1,	/* 4, 3 左上方向 */

	21, 13,  5, -1, -1, -1, -1, -1,	/* 5, 3 上方向 */
	22, 15, -1, -1, -1, -1, -1, -1,	/* 5, 3 右上方向 */
	30, 31, -1, -1, -1, -1, -1, -1,	/* 5, 3 右方向 */
	38, 47, -1, -1, -1, -1, -1, -1,	/* 5, 3 右下方向 */
	37, 45, 53, 61, -1, -1, -1, -1,	/* 5, 3 下方向 */
	36, 43, 50, 57, -1, -1, -1, -1,	/* 5, 3 左下方向 */
	28, 27, 26, 25, 24, -1, -1, -1,	/* 5, 3 左方向 */
	20, 11,  2, -1, -1, -1, -1, -1,	/* 5, 3 左上方向 */

	22, 14,  6, -1, -1, -1, -1, -1,	/* 6, 3 上方向 */
	38, 46, 54, 62, -1, -1, -1, -1,	/* 6, 3 下方向 */
	37, 44, 51, 58, -1, -1, -1, -1,	/* 6, 3 左下方向 */
	29, 28, 27, 26, 25, 24, -1, -1,	/* 6, 3 左方向 */
	21, 12,  3, -1, -1, -1, -1, -1,	/* 6, 3 左上方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 6, 3 右上方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 6, 3 右方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 6, 3 右下方向 */

	23, 15,  7, -1, -1, -1, -1, -1,	/* 7, 3 上方向 */
	39, 47, 55, 63, -1, -1, -1, -1,	/* 7, 3 下方向 */
	38, 45, 52, 59, -1, -1, -1, -1,	/* 7, 3 左下方向 */
	30, 29, 28, 27, 26, 25, 24, -1,	/* 7, 3 左方向 */
	22, 13,  4, -1, -1, -1, -1, -1,	/* 7, 3 左上方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 7, 3 右上方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 7, 3 右方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 7, 3 右下方向 */

	24, 16,  8,  0, -1, -1, -1, -1,	/* 0, 4 上方向 */
	25, 18, 11,  4, -1, -1, -1, -1,	/* 0, 4 右上方向 */
	33, 34, 35, 36, 37, 38, 39, -1,	/* 0, 4 右方向 */
	41, 50, 59, -1, -1, -1, -1, -1,	/* 0, 4 右下方向 */
	40, 48, 56, -1, -1, -1, -1, -1,	/* 0, 4 下方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 0, 4 左下方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 0, 4 左方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 0, 4 左上方向 */

	25, 17,  9,  1, -1, -1, -1, -1,	/* 1, 4 上方向 */
	26, 19, 12,  5, -1, -1, -1, -1,	/* 1, 4 右上方向 */
	34, 35, 36, 37, 38, 39, -1, -1,	/* 1, 4 右方向 */
	42, 51, 60, -1, -1, -1, -1, -1,	/* 1, 4 右下方向 */
	41, 49, 57, -1, -1, -1, -1, -1,	/* 1, 4 下方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 1, 4 左下方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 1, 4 左方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 1, 4 左上方向 */

	26, 18, 10,  2, -1, -1, -1, -1,	/* 2, 4 上方向 */
	27, 20, 13,  6, -1, -1, -1, -1,	/* 2, 4 右上方向 */
	35, 36, 37, 38, 39, -1, -1, -1,	/* 2, 4 右方向 */
	43, 52, 61, -1, -1, -1, -1, -1,	/* 2, 4 右下方向 */
	42, 50, 58, -1, -1, -1, -1, -1,	/* 2, 4 下方向 */
	41, 48, -1, -1, -1, -1, -1, -1,	/* 2, 4 左下方向 */
	33, 32, -1, -1, -1, -1, -1, -1,	/* 2, 4 左方向 */
	25, 16, -1, -1, -1, -1, -1, -1,	/* 2, 4 左上方向 */

	27, 19, 11,  3, -1, -1, -1, -1,	/* 3, 4 上方向 */
	28, 21, 14,  7, -1, -1, -1, -1,	/* 3, 4 右上方向 */
	36, 37, 38, 39, -1, -1, -1, -1,	/* 3, 4 右方向 */
	44, 53, 62, -1, -1, -1, -1, -1,	/* 3, 4 右下方向 */
	43, 51, 59, -1, -1, -1, -1, -1,	/* 3, 4 下方向 */
	42, 49, 56, -1, -1, -1, -1, -1,	/* 3, 4 左下方向 */
	34, 33, 32, -1, -1, -1, -1, -1,	/* 3, 4 左方向 */
	26, 17,  8, -1, -1, -1, -1, -1,	/* 3, 4 左上方向 */

	28, 20, 12,  4, -1, -1, -1, -1,	/* 4, 4 上方向 */
	29, 22, 15, -1, -1, -1, -1, -1,	/* 4, 4 右上方向 */
	37, 38, 39, -1, -1, -1, -1, -1,	/* 4, 4 右方向 */
	45, 54, 63, -1, -1, -1, -1, -1,	/* 4, 4 右下方向 */
	44, 52, 60, -1, -1, -1, -1, -1,	/* 4, 4 下方向 */
	43, 50, 57, -1, -1, -1, -1, -1,	/* 4, 4 左下方向 */
	35, 34, 33, 32, -1, -1, -1, -1,	/* 4, 4 左方向 */
	27, 18,  9,  0, -1, -1, -1, -1,	/* 4, 4 左上方向 */

	29, 21, 13,  5, -1, -1, -1, -1,	/* 5, 4 上方向 */
	30, 23, -1, -1, -1, -1, -1, -1,	/* 5, 4 右上方向 */
	38, 39, -1, -1, -1, -1, -1, -1,	/* 5, 4 右方向 */
	46, 55, -1, -1, -1, -1, -1, -1,	/* 5, 4 右下方向 */
	45, 53, 61, -1, -1, -1, -1, -1,	/* 5, 4 下方向 */
	44, 51, 58, -1, -1, -1, -1, -1,	/* 5, 4 左下方向 */
	36, 35, 34, 33, 32, -1, -1, -1,	/* 5, 4 左方向 */
	28, 19, 10,  1, -1, -1, -1, -1,	/* 5, 4 左上方向 */

	30, 22, 14,  6, -1, -1, -1, -1,	/* 6, 4 上方向 */
	46, 54, 62, -1, -1, -1, -1, -1,	/* 6, 4 下方向 */
	45, 52, 59, -1, -1, -1, -1, -1,	/* 6, 4 左下方向 */
	37, 36, 35, 34, 33, 32, -1, -1,	/* 6, 4 左方向 */
	29, 20, 11,  2, -1, -1, -1, -1,	/* 6, 4 左上方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 6, 4 右上方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 6, 4 右方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 6, 4 右下方向 */

	31, 23, 15,  7, -1, -1, -1, -1,	/* 7, 4 上方向 */
	47, 55, 63, -1, -1, -1, -1, -1,	/* 7, 4 下方向 */
	46, 53, 60, -1, -1, -1, -1, -1,	/* 7, 4 左下方向 */
	38, 37, 36, 35, 34, 33, 32, -1,	/* 7, 4 左方向 */
	30, 21, 12,  3, -1, -1, -1, -1,	/* 7, 4 左上方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 7, 4 右上方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 7, 4 右方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 7, 4 右下方向 */

	32, 24, 16,  8,  0, -1, -1, -1,	/* 0, 5 上方向 */
	33, 26, 19, 12,  5, -1, -1, -1,	/* 0, 5 右上方向 */
	41, 42, 43, 44, 45, 46, 47, -1,	/* 0, 5 右方向 */
	49, 58, -1, -1, -1, -1, -1, -1,	/* 0, 5 右下方向 */
	48, 56, -1, -1, -1, -1, -1, -1,	/* 0, 5 下方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 0, 5 左下方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 0, 5 左方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 0, 5 左上方向 */

	33, 25, 17,  9,  1, -1, -1, -1,	/* 1, 5 上方向 */
	34, 27, 20, 13,  6, -1, -1, -1,	/* 1, 5 右上方向 */
	42, 43, 44, 45, 46, 47, -1, -1,	/* 1, 5 右方向 */
	50, 59, -1, -1, -1, -1, -1, -1,	/* 1, 5 右下方向 */
	49, 57, -1, -1, -1, -1, -1, -1,	/* 1, 5 下方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 1, 5 左下方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 1, 5 左方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 1, 5 左上方向 */

	34, 26, 18, 10,  2, -1, -1, -1,	/* 2, 5 上方向 */
	35, 28, 21, 14,  7, -1, -1, -1,	/* 2, 5 右上方向 */
	43, 44, 45, 46, 47, -1, -1, -1,	/* 2, 5 右方向 */
	51, 60, -1, -1, -1, -1, -1, -1,	/* 2, 5 右下方向 */
	50, 58, -1, -1, -1, -1, -1, -1,	/* 2, 5 下方向 */
	49, 56, -1, -1, -1, -1, -1, -1,	/* 2, 5 左下方向 */
	41, 40, -1, -1, -1, -1, -1, -1,	/* 2, 5 左方向 */
	33, 24, -1, -1, -1, -1, -1, -1,	/* 2, 5 左上方向 */

	35, 27, 19, 11,  3, -1, -1, -1,	/* 3, 5 上方向 */
	36, 29, 22, 15, -1, -1, -1, -1,	/* 3, 5 右上方向 */
	44, 45, 46, 47, -1, -1, -1, -1,	/* 3, 5 右方向 */
	52, 61, -1, -1, -1, -1, -1, -1,	/* 3, 5 右下方向 */
	51, 59, -1, -1, -1, -1, -1, -1,	/* 3, 5 下方向 */
	50, 57, -1, -1, -1, -1, -1, -1,	/* 3, 5 左下方向 */
	42, 41, 40, -1, -1, -1, -1, -1,	/* 3, 5 左方向 */
	34, 25, 16, -1, -1, -1, -1, -1,	/* 3, 5 左上方向 */

	36, 28, 20, 12,  4, -1, -1, -1,	/* 4, 5 上方向 */
	37, 30, 23, -1, -1, -1, -1, -1,	/* 4, 5 右上方向 */
	45, 46, 47, -1, -1, -1, -1, -1,	/* 4, 5 右方向 */
	53, 62, -1, -1, -1, -1, -1, -1,	/* 4, 5 右下方向 */
	52, 60, -1, -1, -1, -1, -1, -1,	/* 4, 5 下方向 */
	51, 58, -1, -1, -1, -1, -1, -1,	/* 4, 5 左下方向 */
	43, 42, 41, 40, -1, -1, -1, -1,	/* 4, 5 左方向 */
	35, 26, 17,  8, -1, -1, -1, -1,	/* 4, 5 左上方向 */

	37, 29, 21, 13,  5, -1, -1, -1,	/* 5, 5 上方向 */
	38, 31, -1, -1, -1, -1, -1, -1,	/* 5, 5 右上方向 */
	46, 47, -1, -1, -1, -1, -1, -1,	/* 5, 5 右方向 */
	54, 63, -1, -1, -1, -1, -1, -1,	/* 5, 5 右下方向 */
	53, 61, -1, -1, -1, -1, -1, -1,	/* 5, 5 下方向 */
	52, 59, -1, -1, -1, -1, -1, -1,	/* 5, 5 左下方向 */
	44, 43, 42, 41, 40, -1, -1, -1,	/* 5, 5 左方向 */
	36, 27, 18,  9,  0, -1, -1, -1,	/* 5, 5 左上方向 */

	38, 30, 22, 14,  6, -1, -1, -1,	/* 6, 5 上方向 */
	54, 62, -1, -1, -1, -1, -1, -1,	/* 6, 5 下方向 */
	53, 60, -1, -1, -1, -1, -1, -1,	/* 6, 5 左下方向 */
	45, 44, 43, 42, 41, 40, -1, -1,	/* 6, 5 左方向 */
	37, 28, 19, 10,  1, -1, -1, -1,	/* 6, 5 左上方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 6, 5 右上方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 6, 5 右方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 6, 5 右下方向 */

	39, 31, 23, 15,  7, -1, -1, -1,	/* 7, 5 上方向 */
	55, 63, -1, -1, -1, -1, -1, -1,	/* 7, 5 下方向 */
	54, 61, -1, -1, -1, -1, -1, -1,	/* 7, 5 左下方向 */
	46, 45, 44, 43, 42, 41, 40, -1,	/* 7, 5 左方向 */
	38, 29, 20, 11,  2, -1, -1, -1,	/* 7, 5 左上方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 7, 5 右上方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 7, 5 右方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 7, 5 右下方向 */

	40, 32, 24, 16,  8,  0, -1, -1,	/* 0, 6 上方向 */
	41, 34, 27, 20, 13,  6, -1, -1,	/* 0, 6 右上方向 */
	49, 50, 51, 52, 53, 54, 55, -1,	/* 0, 6 右方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 0, 6 右下方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 0, 6 下方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 0, 6 左下方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 0, 6 左方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 0, 6 左上方向 */

	41, 33, 25, 17,  9,  1, -1, -1,	/* 1, 6 上方向 */
	42, 35, 28, 21, 14,  7, -1, -1,	/* 1, 6 右上方向 */
	50, 51, 52, 53, 54, 55, -1, -1,	/* 1, 6 右方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 1, 6 右下方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 1, 6 下方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 1, 6 左下方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 1, 6 左方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 1, 6 左上方向 */

	42, 34, 26, 18, 10,  2, -1, -1,	/* 2, 6 上方向 */
	43, 36, 29, 22, 15, -1, -1, -1,	/* 2, 6 右上方向 */
	51, 52, 53, 54, 55, -1, -1, -1,	/* 2, 6 右方向 */
	49, 48, -1, -1, -1, -1, -1, -1,	/* 2, 6 左方向 */
	41, 32, -1, -1, -1, -1, -1, -1,	/* 2, 6 左上方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 2, 6 右下方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 2, 6 下方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 2, 6 左下方向 */

	43, 35, 27, 19, 11,  3, -1, -1,	/* 3, 6 上方向 */
	44, 37, 30, 23, -1, -1, -1, -1,	/* 3, 6 右上方向 */
	52, 53, 54, 55, -1, -1, -1, -1,	/* 3, 6 右方向 */
	50, 49, 48, -1, -1, -1, -1, -1,	/* 3, 6 左方向 */
	42, 33, 24, -1, -1, -1, -1, -1,	/* 3, 6 左上方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 3, 6 右下方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 3, 6 下方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 3, 6 左下方向 */

	44, 36, 28, 20, 12,  4, -1, -1,	/* 4, 6 上方向 */
	45, 38, 31, -1, -1, -1, -1, -1,	/* 4, 6 右上方向 */
	53, 54, 55, -1, -1, -1, -1, -1,	/* 4, 6 右方向 */
	51, 50, 49, 48, -1, -1, -1, -1,	/* 4, 6 左方向 */
	43, 34, 25, 16, -1, -1, -1, -1,	/* 4, 6 左上方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 4, 6 右下方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 4, 6 下方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 4, 6 左下方向 */

	45, 37, 29, 21, 13,  5, -1, -1,	/* 5, 6 上方向 */
	46, 39, -1, -1, -1, -1, -1, -1,	/* 5, 6 右上方向 */
	54, 55, -1, -1, -1, -1, -1, -1,	/* 5, 6 右方向 */
	52, 51, 50, 49, 48, -1, -1, -1,	/* 5, 6 左方向 */
	44, 35, 26, 17,  8, -1, -1, -1,	/* 5, 6 左上方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 5, 6 右下方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 5, 6 下方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 5, 6 左下方向 */

	46, 38, 30, 22, 14,  6, -1, -1,	/* 6, 6 上方向 */
	53, 52, 51, 50, 49, 48, -1, -1,	/* 6, 6 左方向 */
	45, 36, 27, 18,  9,  0, -1, -1,	/* 6, 6 左上方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 6, 6 右上方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 6, 6 右方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 6, 6 右下方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 6, 6 下方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 6, 6 左下方向 */

	47, 39, 31, 23, 15,  7, -1, -1,	/* 7, 6 上方向 */
	54, 53, 52, 51, 50, 49, 48, -1,	/* 7, 6 左方向 */
	46, 37, 28, 19, 10,  1, -1, -1,	/* 7, 6 左上方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 7, 6 右上方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 7, 6 右方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 7, 6 右下方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 7, 6 下方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 7, 6 左下方向 */

	48, 40, 32, 24, 16,  8,  0, -1,	/* 0, 7 上方向 */
	57, 58, 59, 60, 61, 62, 63, -1,	/* 0, 7 右方向 */
	49, 42, 35, 28, 21, 14,  7, -1,	/* 0, 7 右上方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 0, 7 右下方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 0, 7 下方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 0, 7 左下方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 0, 7 左方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 0, 7 左上方向 */

	49, 41, 33, 25, 17,  9,  1, -1,	/* 1, 7 上方向 */
	50, 43, 36, 29, 22, 15, -1, -1,	/* 1, 7 右上方向 */
	58, 59, 60, 61, 62, 63, -1, -1,	/* 1, 7 右方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 1, 7 左方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 1, 7 左上方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 1, 7 右下方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 1, 7 下方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 1, 7 左下方向 */

	50, 42, 34, 26, 18, 10,  2, -1,	/* 2, 7 上方向 */
	51, 44, 37, 30, 23, -1, -1, -1,	/* 2, 7 右上方向 */
	59, 60, 61, 62, 63, -1, -1, -1,	/* 2, 7 右方向 */
	57, 56, -1, -1, -1, -1, -1, -1,	/* 2, 7 左方向 */
	49, 40, -1, -1, -1, -1, -1, -1,	/* 2, 7 左上方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 2, 7 右下方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 2, 7 下方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 2, 7 左下方向 */

	51, 43, 35, 27, 19, 11,  3, -1,	/* 3, 7 上方向 */
	52, 45, 38, 31, -1, -1, -1, -1,	/* 3, 7 右上方向 */
	60, 61, 62, 63, -1, -1, -1, -1,	/* 3, 7 右方向 */
	58, 57, 56, -1, -1, -1, -1, -1,	/* 3, 7 左方向 */
	50, 41, 32, -1, -1, -1, -1, -1,	/* 3, 7 左上方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 3, 7 右下方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 3, 7 下方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 3, 7 左下方向 */

	52, 44, 36, 28, 20, 12,  4, -1,	/* 4, 7 上方向 */
	53, 46, 39, -1, -1, -1, -1, -1,	/* 4, 7 右上方向 */
	61, 62, 63, -1, -1, -1, -1, -1,	/* 4, 7 右方向 */
	59, 58, 57, 56, -1, -1, -1, -1,	/* 4, 7 左方向 */
	51, 42, 33, 24, -1, -1, -1, -1,	/* 4, 7 左上方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 4, 7 右下方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 4, 7 下方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 4, 7 左下方向 */

	53, 45, 37, 29, 21, 13,  5, -1,	/* 5, 7 上方向 */
	54, 47, -1, -1, -1, -1, -1, -1,	/* 5, 7 右上方向 */
	62, 63, -1, -1, -1, -1, -1, -1,	/* 5, 7 右方向 */
	60, 59, 58, 57, 56, -1, -1, -1,	/* 5, 7 左方向 */
	52, 43, 34, 25, 16, -1, -1, -1,	/* 5, 7 左上方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 5, 7 右下方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 5, 7 下方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 5, 7 左下方向 */

	54, 46, 38, 30, 22, 14,  6, -1,	/* 6, 7 上方向 */
	61, 60, 59, 58, 57, 56, -1, -1,	/* 6, 7 左方向 */
	53, 44, 35, 26, 17,  8, -1, -1,	/* 6, 7 左上方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 6, 7 右上方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 6, 7 右方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 6, 7 右下方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 6, 7 下方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 6, 7 左下方向 */

	55, 47, 39, 31, 23, 15,  7, -1,	/* 7, 7 上方向 */
	62, 61, 60, 59, 58, 57, 56, -1,	/* 7, 7 左方向 */
	54, 45, 36, 27, 18,  9,  0, -1,	/* 7, 7 左上方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 7, 7 右上方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 7, 7 右方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 7, 7 右下方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 7, 7 下方向 */
	-1, -1, -1, -1, -1, -1, -1, -1,	/* 7, 7 左下方向 */
};

/* end of file */

